@@ -1,14 +1,15 @@
 """Get the "last updated" time for each Sphinx page from Git."""
-import datetime
+from datetime import datetime, timezone
 from pathlib import Path
 import subprocess
 
+import sphinx.errors
 from sphinx.locale import _
 from sphinx.util.i18n import format_date
 from sphinx.util.logging import getLogger
 
 
-__version__ = '0.1.1'
+__version__ = '0.2.0'
 
 
 logger = getLogger(__name__)
@@ -29,7 +30,7 @@ def get_datetime(path):
     def run_command(cmd):
         return subprocess.check_output(
             cmd,
-            cwd=path.parent,
+            cwd=str(path.parent),
             stderr=subprocess.PIPE,
             universal_newlines=True,
         )
@@ -44,7 +45,7 @@ def get_datetime(path):
         result = run_command(['git', 'rev-parse', '--is-shallow-repository'])
         if result.rstrip('\n') == 'true':
             raise TooShallow(path)
-    return datetime.datetime.fromtimestamp(int(timestamp))
+    return datetime.fromtimestamp(int(timestamp), timezone.utc).astimezone()
 
 
 def _html_page_context(app, pagename, templatename, context, doctree):
@@ -57,11 +58,9 @@ def _html_page_context(app, pagename, templatename, context, doctree):
     try:
         dates.append(get_datetime(sourcefile))
     except subprocess.CalledProcessError as e:
-        logger.warning('Git error:\n%s', e.stderr, location=pagename)
-        return
+        raise sphinx.errors.ExtensionError(e.stderr, e)
     except FileNotFoundError as e:
-        logger.warning('"git" command not found: %s', e, location=pagename)
-        return
+        raise sphinx.errors.ExtensionError('"git" command not found', e)
     except NotInRepository:
         if not app.config.git_untracked_show_sourcelink:
             del context['sourcename']
@@ -83,8 +82,9 @@ def _html_page_context(app, pagename, templatename, context, doctree):
 
     if not dates:
         if shallow:
-            logger.info(
-                '%s: Git clone too shallow', __name__, location=pagename)
+            logger.warning(
+                'Git clone too shallow', location=pagename,
+                type='git', subtype='too_shallow')
         return
 
     context['last_updated'] = format_date(
